==> powerdevil-5.2.2.tar.xz: powerdevil-5.2.2/daemon/actions/bundled/dimdisplayconfig.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#ifndef POWERDEVIL_BUNDLEDACTIONS_DIMDISPLAYCONFIG_H
#define POWERDEVIL_BUNDLEDACTIONS_DIMDISPLAYCONFIG_H

#include <powerdevilactionconfig.h>

class QSpinBox;

namespace PowerDevil {
namespace BundledActions {

class DimDisplayConfig : public PowerDevil::ActionConfig
{
    Q_OBJECT
    Q_DISABLE_COPY(DimDisplayConfig)
public:
    DimDisplayConfig(QObject *, const QVariantList&);
    virtual ~DimDisplayConfig();

    virtual void save();
    virtual void load();
    virtual QList< QPair< QString, QWidget* > > buildUi();

private:
    QSpinBox *m_spinBox;
};

}

}

#endif // POWERDEVIL_BUNDLEDACTIONS_DIMDISPLAYCONFIG_H

==> powerdevil-5.10.95.tar.xz: powerdevil-5.10.95/daemon/actions/bundled/dimdisplayconfig.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Dario Freddi <drf@kde.org>                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/


#ifndef POWERDEVIL_BUNDLEDACTIONS_DIMDISPLAYCONFIG_H
#define POWERDEVIL_BUNDLEDACTIONS_DIMDISPLAYCONFIG_H

#include <powerdevilactionconfig.h>

class QSpinBox;

namespace PowerDevil {
namespace BundledActions {

class DimDisplayConfig : public PowerDevil::ActionConfig
{
    Q_OBJECT
    Q_DISABLE_COPY(DimDisplayConfig)
public:
    DimDisplayConfig(QObject *, const QVariantList&);
    virtual ~DimDisplayConfig();

    void save() Q_DECL_OVERRIDE;
    void load() Q_DECL_OVERRIDE;
    QList< QPair< QString, QWidget* > > buildUi() Q_DECL_OVERRIDE;

private:
    QSpinBox *m_spinBox;
};

}

}

#endif // POWERDEVIL_BUNDLEDACTIONS_DIMDISPLAYCONFIG_H
